# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import atexit
from pathlib import Path
import shutil
import tempfile
from typing import List

from synthtool import log


_tempdirs: List[str] = []


def tmpdir() -> Path:
    path = tempfile.mkdtemp()
    _tempdirs.append(path)
    return Path(path)


def cleanup():
    for path in _tempdirs:
        shutil.rmtree(str(path))
    log.debug(f"Cleaned up {len(_tempdirs)} temporary directories.")


atexit.register(cleanup)
